@@ -23,7 +23,8 @@
 
 struct Rules;
 class LayoutUnit;
-template<typename T> class QList;
+template<typename T>
+class QList;
 
 class KeyboardLayoutActionCollection : public KActionCollection
 {
@@ -32,7 +33,7 @@ public:
     ~KeyboardLayoutActionCollection() override;
 
     QAction *getToggleAction();
-    QAction *createLayoutShortcutActon(const LayoutUnit &layoutUnit, const Rules *rules, bool autoload);
+    QAction *createLayoutShortcutActon(const LayoutUnit &layoutUnit, int layoutIndex, const Rules *rules, bool autoload);
     void setLayoutShortcuts(QList<LayoutUnit> &layoutUnits, const Rules *rules);
     void setToggleShortcut(const QKeySequence &keySequence);
     void loadLayoutShortcuts(QList<LayoutUnit> &layoutUnits, const Rules *rules);
