@@ -21,14 +21,13 @@
 #define INPUTBACKEND_H
 
 #include <QObject>
-#include <QVector>
 #include <QVariantHash>
-
+#include <QVector>
 
 enum class InputBackendMode {
     KWinWayland = 0,
     XLibinput = 1,
-    XEvdev = 2
+    XEvdev = 2,
 };
 
 class InputBackend : public QObject
@@ -36,35 +35,73 @@ class InputBackend : public QObject
     Q_OBJECT
 
 protected:
-    explicit InputBackend(QObject *parent) : QObject(parent) {}
+    explicit InputBackend(QObject *parent)
+        : QObject(parent)
+    {
+    }
     InputBackendMode m_mode;
 
 public:
     static InputBackend *implementation(QObject *parent = nullptr);
 
-    InputBackendMode mode() {
+    InputBackendMode mode()
+    {
         return m_mode;
     }
 
-    virtual void kcmInit() {}
+    virtual void kcmInit()
+    {
+    }
 
-    virtual bool isValid() const { return false; }
+    virtual bool isValid() const
+    {
+        return false;
+    }
 
-    virtual void load() {}
+    virtual void load()
+    {
+    }
 
-    virtual bool applyConfig(const QVariantHash &) { return false; }
-    virtual bool getConfig(QVariantHash &) { return false; }
+    virtual bool applyConfig(const QVariantHash &)
+    {
+        return false;
+    }
+    virtual bool getConfig(QVariantHash &)
+    {
+        return false;
+    }
 
-    virtual bool applyConfig() { return false; }
-    virtual bool getConfig() { return false; }
+    virtual bool applyConfig()
+    {
+        return false;
+    }
+    virtual bool getConfig()
+    {
+        return false;
+    }
 
-    virtual bool getDefaultConfig() { return false; }
-    virtual bool isChangedConfig() const { return false; }
+    virtual bool getDefaultConfig()
+    {
+        return false;
+    }
+    virtual bool isChangedConfig() const
+    {
+        return false;
+    }
 
-    virtual QString errorString() const { return QString(); }
+    virtual QString errorString() const
+    {
+        return QString();
+    }
 
-    virtual int deviceCount() const { return 0; }
-    virtual QVector<QObject*> getDevices() const { return QVector<QObject*>(); }
+    virtual int deviceCount() const
+    {
+        return 0;
+    }
+    virtual QVector<QObject *> getDevices() const
+    {
+        return QVector<QObject *>();
+    }
 
 Q_SIGNALS:
     void deviceAdded(bool success);
